@@ -10,7 +10,7 @@ use IO::Socket;
 use IO::Socket::SSL;
 use Time::Crontab;
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 sub new {
     my $class = shift;
@@ -100,7 +100,10 @@ sub _parent {
             chomp($line);
 
             if ( not $session->{established} ) {
-                if ( not $session->{user} ) {
+                if ( $line =~ /^(ERROR)\s/ ) {
+                    die $line . "\n";
+                }
+                elsif ( not $session->{user} ) {
                     $self->say("USER $self->{nick} 0 * :$self->{connect}{name}");
                     $self->say("NICK $self->{nick}");
                     $session->{user} = 1;
@@ -140,11 +143,16 @@ sub _on_message {
         $self->{in}{$_} = 0 for ( qw( private to_me ) );
         $self->{in}{line} = $line;
 
-        if ( $line =~ /^:(\S+?)!~?(\S+?)@(\S+?)\s(\S+)\s(\S+)\s:(.*)/ ) {
+        if ( $line =~ /^(ERROR)\s/ ) {
+            warn $line . "\n";
+        }
+        elsif ( $line =~ /^:(\S+?)!~?(\S+?)@(\S+?)\s(\S+)\s(\S+)\s:(.*)/ ) {
             @{ $self->{in} }{ qw( nick user server command forum text ) } = ( $1, $2, $3, $4, $5, $6 );
         }
         elsif ( $line =~ /^:(\S+?)!~?(\S+?)@(\S+?)\s(\S+)\s:(.*)/ ) {
             @{ $self->{in} }{ qw( nick user server command text ) } = ( $1, $2, $3, $4, $5 );
+            ( $self->{in}{forum} = $self->{in}{text} ) =~ s/^://
+                if ( $self->{in}{command} eq 'JOIN' or $self->{in}{command} eq 'PART' );
         }
         elsif ( $line =~ /^:(\S+?)!~?(\S+?)@(\S+?)\s(\S+)\s(\S+)\s(.*)/ ) {
             @{ $self->{in} }{ qw( nick user server command forum text ) } = ( $1, $2, $3, $4, $5, $6 );
@@ -160,9 +168,6 @@ sub _on_message {
         elsif ( $line =~ /^:(\S+)\s([A-Z]+|\d+)\s(\S+)\s(.*)/ ) {
             @{ $self->{in} }{ qw( source command forum text ) } = ( $1, $2, $3, $4 );
         }
-        elsif ( $line =~ /^(ERROR)\s/ ) {
-            warn $line . "\n";
-        }
         else {
             warn 'Unparsed line (probably a bug in Bot::IRC; please report it): ', $line . "\n";
         }
@@ -225,13 +230,16 @@ sub load {
     for my $plugin (@_) {
         unless ( ref $plugin ) {
             if ( $plugin =~ /^:core$/i ) {
-                $self->load( qw(
-                    Math
-                    Convert
-                    Join
-                    Seen
-                    Karma
-                ) );
+                $self->load(
+                    'Infobot',
+                    'Functions',
+                    'Convert',
+                    'Join',
+                    'Seen',
+                    'Karma',
+                    'Math',
+                    'Greeting',
+                );
                 next;
             }
 
@@ -442,7 +450,7 @@ Bot::IRC - Yet Another IRC Bot
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC)
@@ -641,9 +649,57 @@ have precedence over "X" which in turn will have precedence over core.
 If you need to allow for variables to get passed to your plugins, an unenforced
 convention is to do so via the C<vars> key to C<new()>.
 
+=head2 Core Plugins
+
 If you specify ":core" as a plugin name, it will be expanded to load all the
-core plugins. (Core plugins are all the plugins that are bundled and
-distributed with L<Bot::IRC>.)
+core plugins. Core plugins are all the plugins that are bundled and
+distributed with L<Bot::IRC>.
+
+=over 4
+
+=item *
+
+L<Bot::IRC::Infobot>
+
+=item *
+
+L<Bot::IRC::Functions>
+
+=item *
+
+L<Bot::IRC::Convert>
+
+=item *
+
+L<Bot::IRC::Join>
+
+=item *
+
+L<Bot::IRC::Seen>
+
+=item *
+
+L<Bot::IRC::Karma>
+
+=item *
+
+L<Bot::IRC::Math>
+
+=item *
+
+L<Bot::IRC::Greeting>
+
+=back
+
+Some core plugins require a storage plugin. If you don't specify one in your
+plugins list, then the default L<Bot::IRC::Store> will be used, which is
+probably not what you want (for performance reasons). Try
+L<Bot::IRC::Store::SQLite> instead.
+
+    plugins => [
+        'Store::SQLite',
+        ':core',
+    ],
 
 =head1 PLUGIN METHODS
 
