@@ -6,7 +6,7 @@ use warnings;
 
 use Math::Units qw(convert);
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -24,7 +24,6 @@ sub init {
             eval { $value = convert( $amount, $m->{in_unit}, $m->{out_unit} ) };
 
             $bot->reply("$m->{amount} $m->{in_unit} is $value $m->{out_unit}") if ($value);
-            return;
         },
     );
 
@@ -45,7 +44,7 @@ Bot::IRC::Convert - Bot::IRC convert units of amounts
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
@@ -61,6 +60,10 @@ version 1.03
 This L<Bot::IRC> plugin allows the bot to convert various values of units.
 Unit types must match, which is to say you can't convert length to volume.
 
+=head2 SEE ALSO
+
+L<Bot::IRC>
+
 =for Pod::Coverage init
 
 =head1 AUTHOR
