@@ -4,7 +4,7 @@ package Bot::IRC::Join;
 use strict;
 use warnings;
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -125,7 +125,7 @@ Bot::IRC::Join - Bot::IRC join and part channels and remember channels state
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
@@ -149,6 +149,10 @@ Join a given channel.
 
 Depart a given channel.
 
+=head2 SEE ALSO
+
+L<Bot::IRC>
+
 =for Pod::Coverage init
 
 =head1 AUTHOR
