@@ -4,7 +4,7 @@ package Bot::IRC::Karma;
 use strict;
 use warnings;
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -12,7 +12,8 @@ sub init {
 
     $bot->hook(
         {
-            text  => qr/(?<thing>\([^\)]+\)|\S+)\s*(?<type>[+-]{2,})(?:\s*#\s*(?<comment>.+))?/,
+            command => 'PRIVMSG',
+            text    => qr/(?<thing>\([^\)]+\)|\S+)\s*(?<type>[+-]{2,})(?:\s*#\s*(?<comment>.+))?/,
         },
         sub {
             my ( $bot, $in, $m ) = @_;
@@ -90,7 +91,7 @@ Bot::IRC::Karma - Bot::IRC track karma for things
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
@@ -125,6 +126,10 @@ Reports the karma of a "thing".
 Tells you one positive and one negative comment (at random) about "thing" if
 there are comments to share.
 
+=head2 SEE ALSO
+
+L<Bot::IRC>
+
 =for Pod::Coverage init
 
 =head1 AUTHOR
