@@ -6,11 +6,11 @@ use warnings;
 
 use Math::Expression;
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 sub init {
     my ($bot) = @_;
-    my $expr = Math::Expression->new;
+    my $expr = Math::Expression->new( PrintErrFunc => sub {} );
 
     $bot->hook(
         {
@@ -20,7 +20,6 @@ sub init {
             my ( $bot, $in ) = @_;
             my $value = $expr->EvalToScalar( $expr->Parse( $in->{text} ) );
             $bot->reply($value) if ($value);
-            return;
         },
     );
 
@@ -41,7 +40,7 @@ Bot::IRC::Math - Bot::IRC evaluate math expressions and return results
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
@@ -61,6 +60,10 @@ See L<Math::Expression> for details. Message text is evaluated with C<Parse>
 and C<EvalToScalar> from L<Math::Expression>. If there's a value generated, the
 bot replies with the value.
 
+=head2 SEE ALSO
+
+L<Bot::IRC>
+
 =for Pod::Coverage init
 
 =head1 AUTHOR
