@@ -7,7 +7,7 @@ use warnings;
 use DateTime;
 use DateTime::Format::Human::Duration;
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -67,7 +67,7 @@ Bot::IRC::Seen - Bot::IRC track when and where users were last seen
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
@@ -87,6 +87,10 @@ were last seen and to report on this when asked. Commands include:
 
 Display last seen information for a given nick.
 
+=head2 SEE ALSO
+
+L<Bot::IRC>
+
 =for Pod::Coverage init
 
 =head1 AUTHOR
