@@ -6,7 +6,7 @@ use warnings;
 
 use YAML::XS qw( LoadFile DumpFile );
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -63,7 +63,7 @@ Bot::IRC::Store - Bot::IRC persistent data storage with YAML
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
@@ -107,6 +107,10 @@ is used.
 
     $bot->register('Bot::IRC::Store');
 
+=head2 SEE ALSO
+
+L<Bot::IRC>
+
 =for Pod::Coverage init new
 
 =head1 AUTHOR
