@@ -8,7 +8,7 @@ use DBI;
 use DBD::SQLite;
 use JSON::XS;
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -88,7 +88,7 @@ Bot::IRC::Store::SQLite - Bot::IRC persistent data storage with SQLite
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
@@ -120,6 +120,10 @@ methods. These operate just like you would expect.
 
     my $score = $bot->store->set('user')->{score};
 
+=head2 SEE ALSO
+
+L<Bot::IRC>
+
 =for Pod::Coverage init new
 
 =head1 AUTHOR
